@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1995-2005, Index Data ApS
+ * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: grs1disp.c,v 1.4 2005/06/25 15:46:04 adam Exp $
+ * $Id: grs1disp.c,v 1.8 2007-05-08 08:22:36 adam Exp $
  */
 
 /**
@@ -16,6 +16,7 @@
 #include <ctype.h>
 
 #include <yaz/proto.h>
+#include <yaz/oid_db.h>
 
 static void display_variant(WRBUF w, Z_Variant *v, int level)
 {
@@ -66,22 +67,27 @@ static void display_grs1(WRBUF w, Z_GenericRecord *r, int level)
             }
         }
         else if (t->content->which == Z_ElementData_string)
-            wrbuf_printf(w, "%s\n", t->content->u.string);
+        {
+            wrbuf_puts(w, t->content->u.string);
+            wrbuf_puts(w, "\n");
+        }
         else if (t->content->which == Z_ElementData_numeric)
+        {
             wrbuf_printf(w, "%d\n", *t->content->u.numeric);
+        }
         else if (t->content->which == Z_ElementData_oid)
         {
-            int *ip = t->content->u.oid;
-            oident *oent;
-            
-            if ((oent = oid_getentbyoid(t->content->u.oid)))
-                wrbuf_printf(w, "OID: %s\n", oent->desc);
-            else
+            Odr_oid *ip = t->content->u.oid;
+
+            if (ip)
             {
-                wrbuf_printf(w, "{");
-                while (ip && *ip >= 0)
-                    wrbuf_printf(w, " %d", *(ip++));
-                wrbuf_printf(w, " }\n");
+                char oid_name_str[OID_STR_MAX];
+                oid_class oclass;
+                const char *oid_name 
+                    = yaz_oid_to_string_buf(ip, &oclass, oid_name_str);
+            
+                if (oid_name)
+                    wrbuf_printf(w, "OID: %s\n", oid_name);
             }
         }
         else if (t->content->which == Z_ElementData_noDataRequested)
