@@ -2,7 +2,7 @@
  * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: icu_I18N.c,v 1.20 2007-11-12 11:11:16 adam Exp $
+ * $Id: icu_I18N.c,v 1.22 2007-12-17 11:23:16 adam Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -166,8 +166,7 @@ struct icu_buf_utf8 * icu_buf_utf8_resize(struct icu_buf_utf8 * buf8,
         else
             buf8->utf8 
                 = (uint8_t *) xrealloc(buf8->utf8, sizeof(uint8_t) * capacity);
-
-        icu_buf_utf8_clear(buf8);
+        
         buf8->utf8_cap = capacity;
     } 
     else { 
@@ -181,23 +180,6 @@ struct icu_buf_utf8 * icu_buf_utf8_resize(struct icu_buf_utf8 * buf8,
 }
 
 
-struct icu_buf_utf8 * icu_buf_utf8_copy(struct icu_buf_utf8 * dest8,
-                                          struct icu_buf_utf8 * src8)
-{
-    if(!dest8 || !src8
-       || dest8 == src8)
-        return 0;
-    
-
-    if (dest8->utf8_cap < src8->utf8_len)
-        icu_buf_utf8_resize(dest8, src8->utf8_len * 2);
-
-    strncpy((char*) dest8->utf8, (char*) src8->utf8, src8->utf8_len);
-
-    return dest8;
-}
-
-
 const char *icu_buf_utf8_to_cstr(struct icu_buf_utf8 *src8)
 {
     if (!src8 || src8->utf8_len == 0)
@@ -465,10 +447,10 @@ int icu_utf16_casemap(struct icu_buf_utf16 * dest16,
 
 
 
-UErrorCode icu_sortkey8_from_utf16(UCollator *coll,
-                                   struct icu_buf_utf8 * dest8, 
-                                   struct icu_buf_utf16 * src16,
-                                   UErrorCode * status)
+void icu_sortkey8_from_utf16(UCollator *coll,
+                             struct icu_buf_utf8 * dest8, 
+                             struct icu_buf_utf16 * src16,
+                             UErrorCode * status)
 { 
   
     int32_t sortkey_len = 0;
@@ -488,8 +470,6 @@ UErrorCode icu_sortkey8_from_utf16(UCollator *coll,
         dest8->utf8_len = sortkey_len;
     else 
         icu_buf_utf8_clear(dest8);
-    
-    return sortkey_len;
 }
 
 
