@@ -1,31 +1,3 @@
-/*
- * Copyright (C) 1995-2005, Index Data ApS
- *
- * Permission to use, copy, modify, distribute, and sell this software and
- * its documentation, in whole or in part, for any purpose, is hereby granted,
- * provided that:
- *
- * 1. This copyright and permission notice appear in all copies of the
- * software and its documentation. Notices of copyright or attribution
- * which appear at the beginning of any file must remain unchanged.
- *
- * 2. The name of Index Data or the individual authors may not be used to
- * endorse or promote products derived from this software without specific
- * prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS, IMPLIED, OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY
- * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
- * IN NO EVENT SHALL INDEX DATA BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
- * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR
- * NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF
- * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
- * OF THIS SOFTWARE.
- *
- * $Id: odr-priv.h,v 1.8 2005/09/09 10:30:35 adam Exp $
- */
-
 /**
  * \file odr-priv.h
  * \brief Internal ODR definitions
@@ -88,7 +60,6 @@ struct Odr_private {
     struct odr_constack *stack_first; /** first member of allocated stack */
     struct odr_constack *stack_top;   /** top of stack */
 
-
     const char **tmp_names_buf;   /** array returned by odr_get_element_path */
     int tmp_names_sz;                 /** size of tmp_names_buf */
 
@@ -100,6 +71,16 @@ struct Odr_private {
     void (*stream_write)(ODR o, void *handle, int type,
                          const char *buf, int len);
     void (*stream_close)(void *handle);
+
+    int can_grow;        /* are we allowed to reallocate */
+    int t_class;         /* implicit tagging (-1==default tag) */
+    int t_tag;
+
+    int enable_bias;     /* force choice enable flag */
+    int choice_bias;     /* force choice */
+    int lenlen;          /* force length-of-lenght (odr_setlen()) */
+    FILE *print;         /* output file handler for direction print */
+    int indent;          /* current indent level for printing */
 };
 
 #define ODR_STACK_POP(x) (x)->op->stack_top = (x)->op->stack_top->prev
