@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1995-2005, Index Data ApS
+ * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: odr_bit.c,v 1.5 2005/06/25 15:46:04 adam Exp $
+ * $Id: odr_bit.c,v 1.7 2007-03-19 21:08:13 adam Exp $
  */
 
 /**
@@ -27,12 +27,13 @@ int odr_bitstring(ODR o, Odr_bitmask **p, int opt, const char *name)
 
     if (o->error)
         return 0;
-    if (o->t_class < 0)
+    if (o->op->t_class < 0)
     {
-        o->t_class = ODR_UNIVERSAL;
-        o->t_tag = ODR_BITSTRING;
+        o->op->t_class = ODR_UNIVERSAL;
+        o->op->t_tag = ODR_BITSTRING;
     }
-    if ((res = ber_tag(o, p, o->t_class, o->t_tag, &cons, opt, name)) < 0)
+    res = ber_tag(o, p, o->op->t_class, o->op->t_tag, &cons, opt, name);
+    if (res < 0)
         return 0;
     if (!res)
         return odr_missing(o, opt, name);
