@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1995-2005, Index Data ApS
+ * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: odr_seq.c,v 1.5 2005/08/11 14:21:55 adam Exp $
+ * $Id: odr_seq.c,v 1.7 2007-03-19 21:08:13 adam Exp $
  */
 /**
  * \file odr_seq.c
@@ -20,14 +20,14 @@ int odr_sequence_begin(ODR o, void *p, int size, const char *name)
 
     if (o->error)
         return 0;
-    if (o->t_class < 0)
+    if (o->op->t_class < 0)
     {
-        o->t_class = ODR_UNIVERSAL;
-        o->t_tag = ODR_SEQUENCE;
+        o->op->t_class = ODR_UNIVERSAL;
+        o->op->t_tag = ODR_SEQUENCE;
     }
     if (o->direction == ODR_DECODE)
         *pp = 0;
-    if (odr_constructed_begin(o, p, o->t_class, o->t_tag, name))
+    if (odr_constructed_begin(o, p, o->op->t_class, o->op->t_tag, name))
     {
         if (o->direction == ODR_DECODE && size)
             *pp = (char *)odr_malloc(o, size);
@@ -43,14 +43,14 @@ int odr_set_begin(ODR o, void *p, int size, const char *name)
 
     if (o->error)
         return 0;
-    if (o->t_class < 0)
+    if (o->op->t_class < 0)
     {
-        o->t_class = ODR_UNIVERSAL;
-        o->t_tag = ODR_SET;
+        o->op->t_class = ODR_UNIVERSAL;
+        o->op->t_tag = ODR_SET;
     }
     if (o->direction == ODR_DECODE)
         *pp = 0;
-    if (odr_constructed_begin(o, p, o->t_class, o->t_tag, name))
+    if (odr_constructed_begin(o, p, o->op->t_class, o->op->t_tag, name))
     {
         if (o->direction == ODR_DECODE && size)
             *pp = (char *)odr_malloc(o, size);
