@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1995-2005, Index Data ApS
+ * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: session.h,v 1.10 2006/03/15 13:32:05 adam Exp $
+ * $Id: session.h,v 1.15 2007-08-13 16:46:19 mike Exp $
  */
 /**
  * \file session.h
@@ -13,10 +13,11 @@
 
 #include <yaz/comstack.h>
 #include <yaz/cql.h>
+#include <yaz/ccl.h>
 #include <yaz/odr.h>
-#include <yaz/oid.h>
 #include <yaz/proto.h>
 #include <yaz/backend.h>
+#include <yaz/retrieval.h>
 #include "eventl.h"
 
 struct gfs_server {
@@ -24,10 +25,12 @@ struct gfs_server {
     char *host;
     int listen_ref;
     cql_transform_t cql_transform;
+    CCL_bibset ccl_transform;
     void *server_node_ptr;
     char *directory;
     char *docpath;
     char *stylesheet;
+    yaz_retrieval_t retrieval;
     struct gfs_server *next;
 };
 
@@ -109,10 +112,8 @@ typedef struct association
 
     struct bend_initrequest *init;
     statserv_options_block *last_control;
-    cql_transform_t cql_transform;
-    void *server_node_ptr;
-    const char *docpath;
-    const char *stylesheet;
+
+    struct gfs_server *server;
 } association;
 
 association *create_association(IOCHAN channel, COMSTACK link,
@@ -133,6 +134,8 @@ int statserv_must_terminate(void);
 
 int control_association(association *assoc, const char *host, int force);
 
+int ir_read(IOCHAN h, int event);
+
 #endif
 /*
  * Local variables:
