@@ -1,11 +1,11 @@
 /*
- * Copyright (C) 1995-2005, Index Data ApS
+ * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
  * NT threaded server code by
  *   Chas Woodfield, Fretwell Downing Informatics.
  *
- * $Id: statserv.c,v 1.36 2006/03/22 17:58:32 mike Exp $
+ * $Id: statserv.c,v 1.52 2007-11-12 08:57:45 adam Exp $
  */
 
 /**
@@ -36,7 +36,7 @@
 #include <pwd.h>
 #endif
 
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <libxml/xinclude.h>
@@ -85,15 +85,13 @@ static statserv_options_block *current_control_block = 0;
 /*
  * default behavior.
  */
-#define STAT_DEFAULT_LOG_LEVEL "none,fatal,warn,log,server,session,request"
-/* the 'none' clears yaz' own default settings, including [log] */
+#define STAT_DEFAULT_LOG_LEVEL "server,session,request"
 
 int check_options(int argc, char **argv);
 statserv_options_block control_block = {
     1,                          /* dynamic mode */
     0,                          /* threaded mode */
     0,                          /* one shot (single session) */
-    0, /* __UNUSED_loglevel */
     "",                         /* no PDUs */
     "",                         /* diagnostic output to stderr */
     "tcp:@:9999",               /* default listener port */
@@ -127,7 +125,8 @@ statserv_options_block control_block = {
 static int max_sessions = 0;
 
 static int logbits_set = 0;
-static int log_session = 0;
+static int log_session = 0; /* one-line logs for session */
+static int log_sessiondetail = 0; /* more detailed stuff */
 static int log_server = 0;
 
 /** get_logbits sets global loglevel bits */
@@ -137,6 +136,7 @@ static void get_logbits(int force)
     {
         logbits_set = 1;
         log_session = yaz_log_module_level("session");
+        log_sessiondetail = yaz_log_module_level("sessiondetail");
         log_server = yaz_log_module_level("server");
     }
 }
@@ -144,12 +144,12 @@ static void get_logbits(int force)
 
 static int add_listener(char *where, int listen_id);
 
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
 static xmlDocPtr xml_config_doc = 0;
 #endif
 
-#if HAVE_XML2
-static xmlNodePtr xml_config_get_root()
+#if YAZ_HAVE_XML2
+static xmlNodePtr xml_config_get_root(void)
 {
     xmlNodePtr ptr = 0;
     if (xml_config_doc)
@@ -168,7 +168,7 @@ static xmlNodePtr xml_config_get_root()
 }
 #endif
 
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
 static char *nmem_dup_xml_content(NMEM n, xmlNodePtr ptr)
 {
     unsigned char *cp;
@@ -183,7 +183,7 @@ static char *nmem_dup_xml_content(NMEM n, xmlNodePtr ptr)
             len += xmlStrlen(p->content);
     }
     /* now allocate for the string */
-    str = nmem_malloc(n, len);
+    str = (unsigned char *) nmem_malloc(n, len);
     *str = '\0'; /* so we can use strcat */
     for (p = ptr; p; p = p->next)
     {
@@ -210,25 +210,31 @@ static char *nmem_dup_xml_content(NMEM n, xmlNodePtr ptr)
 }
 #endif
 
-static struct gfs_server * gfs_server_new()
+static struct gfs_server * gfs_server_new(void)
 {
-    struct gfs_server *n = nmem_malloc(gfs_nmem, sizeof(*n));
+    struct gfs_server *n = (struct gfs_server *)
+        nmem_malloc(gfs_nmem, sizeof(*n));
     memcpy(&n->cb, &control_block, sizeof(control_block));
     n->next = 0;
     n->host = 0;
     n->listen_ref = 0;
     n->cql_transform = 0;
+    n->ccl_transform = 0;
     n->server_node_ptr = 0;
     n->directory = 0;
     n->docpath = 0;
     n->stylesheet = 0;
+#if YAZ_HAVE_XML2
+    n->retrieval = yaz_retrieval_create();
+#endif
     return n;
 }
 
 static struct gfs_listen * gfs_listen_new(const char *id, 
                                           const char *address)
 {
-    struct gfs_listen *n = nmem_malloc(gfs_nmem, sizeof(*n));
+    struct gfs_listen *n = (struct gfs_listen *)
+        nmem_malloc(gfs_nmem, sizeof(*n));
     if (id)
         n->id = nmem_strdup(gfs_nmem, id);
     else
@@ -265,10 +271,7 @@ int control_association(association *assoc, const char *host, int force_open)
             *cp = '\0';
         host = vhost;
     }
-    assoc->cql_transform = 0;
-    assoc->server_node_ptr = 0;
-    assoc->docpath = 0;
-    assoc->stylesheet = 0;
+    assoc->server = 0;
     if (control_block.xml_config[0])
     {
         struct gfs_server *gfs;
@@ -296,36 +299,40 @@ int control_association(association *assoc, const char *host, int force_open)
                     xfree(assoc->init);
                     assoc->init = 0;
                 }
-                assoc->docpath = gfs->docpath;
-                assoc->stylesheet = gfs->stylesheet;
-                assoc->cql_transform = gfs->cql_transform;
-                assoc->server_node_ptr = gfs->server_node_ptr;
+                assoc->server = gfs;
                 assoc->last_control = &gfs->cb;
                 statserv_setcontrol(&gfs->cb);
+                
                 gfs_server_chdir(gfs);
-                yaz_log(YLOG_DEBUG, "server select: %s", gfs->cb.configname);
-                return 1;
+                break;
             }
         }
-        statserv_setcontrol(0);
-        assoc->last_control = 0;
-        yaz_log(YLOG_DEBUG, "server select: no match");
-        return 0;
+        if (!gfs)
+        {
+            statserv_setcontrol(0);
+            assoc->last_control = 0;
+            return 0;
+        }
     }
     else
     {
         statserv_setcontrol(&control_block);
         assoc->last_control = &control_block;
-        yaz_log(YLOG_DEBUG, "server select: config=%s", control_block.configname);
-        return 1;
     }
+    yaz_log(YLOG_DEBUG, "server select: config=%s", 
+            assoc->last_control->configname);
+
+    assoc->maximumRecordSize = assoc->last_control->maxrecordsize;
+    assoc->preferredMessageSize = assoc->last_control->maxrecordsize;
+    cs_set_max_recv_bytes(assoc->client_link, assoc->maximumRecordSize);
+    return 1;
 }
 
-static void xml_config_read()
+static void xml_config_read(void)
 {
     struct gfs_server **gfsp = &gfs_server_list;
     struct gfs_listen **gfslp = &gfs_listen_list;
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
     xmlNodePtr ptr = xml_config_get_root();
 
     if (!ptr)
@@ -361,6 +368,7 @@ static void xml_config_read()
             xmlNodePtr ptr;
             const char *listenref = 0;
             const char *id = 0;
+            struct gfs_server *gfs;
 
             for ( ; attr; attr = attr->next)
                 if (!xmlStrcmp(attr->name, BAD_CAST "listenref") 
@@ -373,8 +381,8 @@ static void xml_config_read()
                 else
                     yaz_log(YLOG_WARN, "Unknown attribute '%s' for server",
                             attr->name);
-            *gfsp = gfs_server_new();
-            (*gfsp)->server_node_ptr = ptr_server;
+            gfs = *gfsp = gfs_server_new();
+            gfs->server_node_ptr = ptr_server;
             if (listenref)
             {
                 int id_no;
@@ -382,7 +390,7 @@ static void xml_config_read()
                 for (id_no = 1; gl; gl = gl->next, id_no++)
                     if (gl->id && !strcmp(gl->id, listenref))
                     {
-                        (*gfsp)->listen_ref = id_no;
+                        gfs->listen_ref = id_no;
                         break;
                     }
                 if (!gl)
@@ -395,41 +403,70 @@ static void xml_config_read()
                     continue;
                 if (!strcmp((const char *) ptr->name, "host"))
                 {
-                    (*gfsp)->host = nmem_dup_xml_content(gfs_nmem,
+                    gfs->host = nmem_dup_xml_content(gfs_nmem,
                                                          ptr->children);
                 }
                 else if (!strcmp((const char *) ptr->name, "config"))
                 {
-                    strcpy((*gfsp)->cb.configname,
+                    strcpy(gfs->cb.configname,
                            nmem_dup_xml_content(gfs_nmem, ptr->children));
                 }
                 else if (!strcmp((const char *) ptr->name, "cql2rpn"))
                 {
-                    (*gfsp)->cql_transform = cql_transform_open_fname(
+                    gfs->cql_transform = cql_transform_open_fname(
                         nmem_dup_xml_content(gfs_nmem, ptr->children)
                         );
                 }
+                else if (!strcmp((const char *) ptr->name, "ccl2rpn"))
+                {
+                    char *name;
+                    FILE *f;
+
+                    name = nmem_dup_xml_content(gfs_nmem, ptr->children);
+                    if ((f = fopen(name, "r")) == 0) {
+                        yaz_log(YLOG_FATAL, "can't open CCL file '%s'", name);
+                        exit(1);
+                    }
+                    gfs->ccl_transform = ccl_qual_mk();
+                    ccl_qual_file (gfs->ccl_transform, f);
+                    fclose(f);
+                }
                 else if (!strcmp((const char *) ptr->name, "directory"))
                 {
-                    (*gfsp)->directory = 
+                    gfs->directory = 
                         nmem_dup_xml_content(gfs_nmem, ptr->children);
                 }
                 else if (!strcmp((const char *) ptr->name, "docpath"))
                 {
-                    (*gfsp)->docpath = 
+                    gfs->docpath = 
                         nmem_dup_xml_content(gfs_nmem, ptr->children);
                 }
+                else if (!strcmp((const char *) ptr->name, "maximumrecordsize"))
+                {
+                    gfs->cb.maxrecordsize = atoi(
+                        nmem_dup_xml_content(gfs_nmem, ptr->children));
+                }
                 else if (!strcmp((const char *) ptr->name, "stylesheet"))
                 {
                     char *s = nmem_dup_xml_content(gfs_nmem, ptr->children);
-                    (*gfsp)->stylesheet = 
+                    gfs->stylesheet = (char *)
                         nmem_malloc(gfs_nmem, strlen(s) + 2);
-                    sprintf((*gfsp)->stylesheet, "/%s", s);
+                    sprintf(gfs->stylesheet, "/%s", s);
                 }
                 else if (!strcmp((const char *) ptr->name, "explain"))
                 {
                     ; /* being processed separately */
                 }
+                else if (!strcmp((const char *) ptr->name, "retrievalinfo"))
+                {
+                    if (yaz_retrieval_configure(gfs->retrieval, ptr))
+                    {       
+                        yaz_log(YLOG_FATAL, "%s in config %s",
+                                yaz_retrieval_get_error(gfs->retrieval),
+                                control_block.xml_config);
+                        exit(1);
+                    }
+                }
                 else
                 {
                     yaz_log(YLOG_FATAL, "Unknown element '%s' in config %s",
@@ -444,7 +481,7 @@ static void xml_config_read()
     *gfsp = 0;
 }
 
-static void xml_config_open()
+static void xml_config_open(void)
 {
     if (!getcwd(gfs_root_dir, FILENAME_MAX))
     {
@@ -460,7 +497,7 @@ static void xml_config_open()
 #endif
     
     gfs_nmem = nmem_create();
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
     if (control_block.xml_config[0] == '\0')
         return;
 
@@ -487,9 +524,9 @@ static void xml_config_open()
 #endif
 }
 
-static void xml_config_close()
+static void xml_config_close(void)
 {
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
     if (xml_config_doc)
     {
         xmlFreeDoc(xml_config_doc);
@@ -507,7 +544,7 @@ static void xml_config_close()
 #endif
 }
 
-static void xml_config_add_listeners()
+static void xml_config_add_listeners(void)
 {
     struct gfs_listen *gfs = gfs_listen_list;
     int id_no;
@@ -519,7 +556,7 @@ static void xml_config_add_listeners()
     }
 }
 
-static void xml_config_bend_start()
+static void xml_config_bend_start(void)
 {
     if (control_block.xml_config[0])
     {
@@ -545,7 +582,7 @@ static void xml_config_bend_start()
     }
 }
 
-static void xml_config_bend_stop()
+static void xml_config_bend_stop(void)
 {
     if (control_block.xml_config[0])
     {
@@ -734,7 +771,7 @@ void statserv_closedown()
 
 void __cdecl event_loop_thread (IOCHAN iochan)
 {
-    event_loop (&iochan);
+    iochan_event_loop (&iochan);
 }
 
 /* WIN32 listener */
@@ -748,27 +785,21 @@ static void listener(IOCHAN h, int event)
 
     if (event == EVENT_INPUT)
     {
+        COMSTACK new_line;
+        IOCHAN new_chan;
+
         if ((res = cs_listen(line, 0, 0)) < 0)
         {
-            yaz_log(YLOG_FATAL, "cs_listen failed");
+            yaz_log(YLOG_FATAL|YLOG_ERRNO, "cs_listen failed");
             return;
         }
         else if (res == 1)
-            return;
+            return; /* incomplete */
         yaz_log(YLOG_DEBUG, "listen ok");
-        iochan_setevent(h, EVENT_OUTPUT);
-        iochan_setflags(h, EVENT_OUTPUT | EVENT_EXCEPT); /* set up for acpt */
-    }
-    else if (event == EVENT_OUTPUT)
-    {
-        COMSTACK new_line = cs_accept(line);
-        IOCHAN new_chan;
-        char *a = NULL;
-
-        if (!new_line)
+        new_line = cs_accept(line);
+	if (!new_line)
         {
             yaz_log(YLOG_FATAL, "Accept failed.");
-            iochan_setflags(h, EVENT_INPUT | EVENT_EXCEPT);
             return;
         }
         yaz_log(YLOG_DEBUG, "Accept ok");
@@ -889,7 +920,7 @@ static void listener(IOCHAN h, int event)
             return;
         }
 
-        yaz_log(log_session, "Connect from %s", cs_addrstr(new_line));
+        yaz_log(log_sessiondetail, "Connect from %s", cs_addrstr(new_line));
 
         no_sessions++;
         if (control_block.dynamic)
@@ -967,7 +998,7 @@ static void *new_session (void *vp)
     association *newas;
     IOCHAN new_chan;
     COMSTACK new_line = (COMSTACK) vp;
-    IOCHAN parent_chan = new_line->user;
+    IOCHAN parent_chan = (IOCHAN) new_line->user;
 
     unsigned cs_get_mask, cs_accept_mask, mask =  
         ((new_line->io_pending & CS_WANT_WRITE) ? EVENT_OUTPUT : 0) |
@@ -1006,13 +1037,13 @@ static void *new_session (void *vp)
 #else
     a = 0;
 #endif
-    yaz_log(log_session, "Starting session %d from %s (pid=%ld)",
+    yaz_log(log_session, "Session - OK %d %s %ld",
             no_sessions, a ? a : "[Unknown]", (long) getpid());
     if (max_sessions && no_sessions >= max_sessions)
         control_block.one_shot = 1;
     if (control_block.threads)
     {
-        event_loop(&new_chan);
+        iochan_event_loop(&new_chan);
     }
     else
     {
@@ -1043,7 +1074,7 @@ static void inetd_connection(int what)
                 iochan_setdata(chan, assoc);
                 iochan_settimeout(chan, 60);
                 addr = cs_addrstr(line);
-                yaz_log(log_session, "Inetd association from %s",
+                yaz_log(log_sessiondetail, "Inetd association from %s",
                         addr ? addr : "[UNKNOWN]");
                 assoc->cs_get_mask = EVENT_INPUT;
             }
@@ -1096,7 +1127,11 @@ static int add_listener(char *where, int listen_id)
 
     if (cs_bind(l, ap, CS_SERVER) < 0)
     {
-        yaz_log(YLOG_FATAL|YLOG_ERRNO, "Failed to bind to %s", where);
+        if (cs_errno(l) == CSYSERR)
+            yaz_log(YLOG_FATAL|YLOG_ERRNO, "Failed to bind to %s", where);
+        else
+            yaz_log(YLOG_FATAL, "Failed to bind to %s: %s", where,
+                    cs_strerror(l));
         cs_close (l);
         return -1;
     }
@@ -1135,7 +1170,8 @@ statserv_options_block *statserv_getcontrol(void)
         return &control_block;
 #elif YAZ_POSIX_THREADS
     if (init_control_tls)
-        return pthread_getspecific(current_control_tls);
+        return (statserv_options_block *)
+            pthread_getspecific(current_control_tls);
     else
         return &control_block;
 #else
@@ -1307,7 +1343,7 @@ int statserv_start(int argc, char **argv)
     if (pListener == NULL)
         return 1;
     yaz_log(YLOG_DEBUG, "Entering event loop.");
-    return event_loop(&pListener);
+    return iochan_event_loop(&pListener);
 }
 
 static void option_copy(char *dst, const char *src)
@@ -1321,19 +1357,10 @@ int check_options(int argc, char **argv)
     int ret = 0, r;
     char *arg;
 
-    if (getenv("YAZ_LOG") == 0) {
-        /*
-         * Set default log level.  We want to avoid doing this if the
-         * user has already explicitly specified a preferred default
-         * log-level, hence the inelegant peek at the YAZ_LOG
-         * environment variable that will subsequently be interpreted
-         * by the YAZ logging module itself.
-         */
-        yaz_log_init_level(yaz_log_mask_str(STAT_DEFAULT_LOG_LEVEL));
-    }
-
+    yaz_log_init_level(yaz_log_mask_str(STAT_DEFAULT_LOG_LEVEL)); 
     get_logbits(1); 
-    while ((ret = options("1a:iszSTl:v:u:c:w:t:k:d:A:p:DC:f:m:",
+
+    while ((ret = options("1a:iszSTl:v:u:c:w:t:k:d:A:p:DC:f:m:r:",
                           argv, argc, &arg)) != -2)
     {
         switch (ret)
@@ -1379,12 +1406,10 @@ int check_options(int argc, char **argv)
             }
             yaz_log_time_format(arg);
             break;
-        case 'v': {
-            int default_level = yaz_log_mask_str(STAT_DEFAULT_LOG_LEVEL);
-            yaz_log_init_level(yaz_log_mask_str_x(arg, default_level));
+        case 'v':
+            yaz_log_init_level(yaz_log_mask_str(arg));
             get_logbits(1); 
             break;
-        }
         case 'a':
             option_copy(control_block.apdufile, arg);
             break;
@@ -1433,7 +1458,7 @@ int check_options(int argc, char **argv)
             option_copy(control_block.pid_fname, arg);
             break;
         case 'f':
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
             option_copy(control_block.xml_config, arg);
 #else
             fprintf(stderr, "%s: Option -f unsupported since YAZ is compiled without Libxml2 support\n", me);
@@ -1443,6 +1468,14 @@ int check_options(int argc, char **argv)
         case 'D':
             control_block.background = 1;
             break;
+        case 'r':
+            if (!arg || !(r = atoi(arg)))
+            {
+                fprintf(stderr, "%s: Specify positive size for -r.\n", me);
+                return(1);
+            }
+            yaz_log_init_max_size(r * 1024);
+            break;
         default:
             fprintf(stderr, "Usage: %s [ -a <pdufile> -v <loglevel>"
                     " -l <logfile> -u <user> -c <config> -t <minutes>"
