@@ -2,18 +2,20 @@
  * Copyright (C) 1995-2005, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: zoom-p.h,v 1.10 2006/03/01 23:24:26 adam Exp $
+ * $Id: zoom-p.h,v 1.25 2007-09-11 08:40:28 adam Exp $
  */
 /**
  * \file zoom-p.h
  * \brief Internal header for ZOOM implementation
  */
-
 #include <yaz/proto.h>
+#include <yaz/oid_db.h>
 #include <yaz/comstack.h>
 #include <yaz/wrbuf.h>
 #include <yaz/zoom.h>
 #include <yaz/sortspec.h>
+#include <yaz/srw.h>
+
 typedef struct ZOOM_Event_p *ZOOM_Event;
 
 struct ZOOM_query_p {
@@ -28,7 +30,7 @@ typedef enum {
     zoom_sru_error,
     zoom_sru_soap,
     zoom_sru_get,
-    zoom_sru_post,
+    zoom_sru_post
 } zoom_sru_mode;
     
 
@@ -38,10 +40,6 @@ typedef struct ZOOM_task_p *ZOOM_task;
 #define STATE_CONNECTING 1
 #define STATE_ESTABLISHED 2
 
-#define ZOOM_SELECT_READ 1
-#define ZOOM_SELECT_WRITE 2
-#define ZOOM_SELECT_EXCEPT 4
-
 struct ZOOM_connection_p {
     enum oid_proto proto;
     COMSTACK cs;
@@ -65,9 +63,19 @@ struct ZOOM_connection_p {
     char *cookie_out;
     char *cookie_in;
     char *client_IP;
+    char *sru_version;
+
+    char *user;
+    char *group;
+    char *password;
+
     int async;
     int support_named_resultsets;
     int last_event;
+
+    int maximum_record_size;
+    int preferred_message_size;
+
     ZOOM_task tasks;
     ZOOM_options options;
     ZOOM_resultset resultsets;
@@ -92,24 +100,27 @@ struct ZOOM_options_p {
     ZOOM_options parent2;
 };
 
+
 typedef struct ZOOM_record_cache_p *ZOOM_record_cache;
 
+#define RECORD_HASH_SIZE  131
+
 struct ZOOM_resultset_p {
     Z_SortKeySpecList *r_sort_spec;
     ZOOM_query query;
     int refcount;
     int size;
-    int start;
-    int count;
     int step;
     int piggyback;
     char *setname;
     char *schema;
     ODR odr;
-    ZOOM_record_cache record_cache;
+    ZOOM_record_cache record_hash[RECORD_HASH_SIZE];
     ZOOM_options options;
     ZOOM_connection connection;
     ZOOM_resultset next;
+    char **databaseNames;
+    int num_databaseNames;
 };
 
 struct ZOOM_record_p {
@@ -118,6 +129,12 @@ struct ZOOM_record_p {
     WRBUF wrbuf_iconv;
     WRBUF wrbuf_opac;
     Z_NamePlusRecord *npr;
+    const char *schema;
+
+    const char *diag_uri;
+    const char *diag_message;
+    const char *diag_details;
+    const char *diag_set;
 };
 
 struct ZOOM_record_cache_p {
@@ -134,9 +151,12 @@ struct ZOOM_scanset_p {
     ODR odr;
     ZOOM_options options;
     ZOOM_connection connection;
-    Z_AttributesPlusTerm *termListAndStartPoint;
-    Z_AttributeSetId *attributeSet;
+    ZOOM_query query;
     Z_ScanResponse *scan_response;
+    Z_SRW_scanResponse *srw_scan_response;
+
+    char **databaseNames;
+    int num_databaseNames;
 };
 
 struct ZOOM_package_p {
@@ -154,13 +174,19 @@ struct ZOOM_task_p {
     union {
 #define ZOOM_TASK_SEARCH 1
         struct {
+            int count;
+            int start;
             ZOOM_resultset resultset;
+            char *syntax;
+            char *elementSetName;
         } search;
 #define ZOOM_TASK_RETRIEVE 2
         struct {
             int start;
             ZOOM_resultset resultset;
             int count;
+            char *syntax;
+            char *elementSetName;
         } retrieve;
 #define ZOOM_TASK_CONNECT 3
 #define ZOOM_TASK_SCAN 4
@@ -185,6 +211,7 @@ struct ZOOM_Event_p {
 };
 
 void ZOOM_options_addref (ZOOM_options opt);
+
 /*
  * Local variables:
  * c-basic-offset: 4
