@@ -2,7 +2,7 @@
  * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: tstccl.c,v 1.13 2007/01/08 10:48:07 adam Exp $
+ * $Id: tstccl.c,v 1.17 2007-04-27 09:48:28 adam Exp $
  */
 
 /* CCL test */
@@ -16,19 +16,14 @@ static int tst_ccl_query(CCL_bibset bibset,
                          const char *query,
                          const char *result)
 {
-    CCL_parser parser = ccl_parser_create();
+    CCL_parser parser = ccl_parser_create(bibset);
     int ret = 0;
 
     if (parser && bibset)
     {
-        struct ccl_token *token_list;
         struct ccl_rpn_node *rpn;
         
-        parser->bibset = bibset;
-        
-        token_list = ccl_parser_tokenize(parser, query);
-        rpn = ccl_parser_find(parser, token_list);
-        ccl_token_del(token_list);
+        rpn = ccl_parser_find_str(parser, query);
         if (rpn)
         {
             /* parse ok. check that result is there and match */
@@ -36,12 +31,12 @@ static int tst_ccl_query(CCL_bibset bibset,
             ccl_pquery(wrbuf, rpn);
             
             /* check expect a result and that it matches */
-            if (result && !strcmp(wrbuf_buf(wrbuf), result))
+            if (result && !strcmp(wrbuf_cstr(wrbuf), result))
                 ret = 1;
             else
                 ret = 0;
             ccl_rpn_delete(rpn);
-            wrbuf_free(wrbuf, 1);
+            wrbuf_destroy(wrbuf);
         }
         else 
         {
@@ -132,6 +127,8 @@ void tst1(int pass)
 
             r = ccl_xml_config(bibset, xmlDocGetRootElement(doc), &addinfo);
             YAZ_CHECK_EQ(r, 0);
+
+            xmlFreeDoc(doc);
         }
         break;
 #else
