@@ -1,14 +1,13 @@
 /*
- * Copyright (C) 1995-2005, Index Data ApS
+ * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: tstodr.c,v 1.8 2006/01/29 21:59:13 adam Exp $
+ * $Id: tstodr.c,v 1.12 2007-08-13 16:23:30 mike Exp $
  *
  */
 #include <stdlib.h>
 #include <stdio.h>
-#include <yaz/odr.h>
-#include <yaz/oid.h>
+#include <yaz/oid_util.h>
 #include "tstodrcodec.h"
 
 #include <yaz/test.h>
@@ -67,7 +66,7 @@ void tst_MySequence1(ODR encode, ODR decode)
     YAZ_CHECK(t->myoid);
     if (t->myoid)
     {
-        int *myoid = odr_getoidbystr(decode, MYOID);
+        Odr_oid *myoid = odr_getoidbystr(decode, MYOID);
 
         YAZ_CHECK(oid_oidcmp(myoid, t->myoid) == 0);
     }
