@@ -1,5 +1,5 @@
-/* $Id: cql2pqf.c,v 1.7 2005/06/25 15:46:07 adam Exp $
-   Copyright (C) 1995-2005, Index Data ApS
+/* $Id: cql2pqf.c,v 1.9 2007-01-03 08:42:16 adam Exp $
+   Copyright (C) 1995-2007, Index Data ApS
    Index Data Aps
 
 This file is part of the YAZ toolkit.
@@ -13,7 +13,7 @@ See the file LICENSE.
 #include <yaz/cql.h>
 #include <yaz/options.h>
 
-static void usage()
+static void usage(void)
 {
     fprintf (stderr, "usage\n cql2pqf [-n <n>] <properties> [<query>]\n");
     exit (1);
