@@ -2,7 +2,7 @@
  * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: marcdump.c,v 1.53 2007-09-23 07:40:13 adam Exp $
+ * $Id: marcdump.c,v 1.55 2007-12-18 21:13:06 adam Exp $
  */
 
 #define _FILE_OFFSET_BITS 64
@@ -14,10 +14,20 @@
 #if YAZ_HAVE_XML2
 #include <libxml/parser.h>
 #include <libxml/tree.h>
-
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
+/* Libxml2 version < 2.6.15. xmlreader not reliable/present */
+#if LIBXML_VERSION < 20615
+#define USE_XMLREADER 0
+#else
+#define USE_XMLREADER 1
+#endif
+
+#if USE_XMLREADER
+#include <libxml/xmlreader.h>
+#endif
+
 #endif
 
 #include <stdio.h>
@@ -93,34 +103,88 @@ static void marcdump_read_line(yaz_marc_t mt, const char *fname)
         fputs(wrbuf_cstr(wrbuf), stdout);
         wrbuf_destroy(wrbuf);
     }
+    {
+        WRBUF wrbuf = wrbuf_alloc();
+        yaz_marc_write_trailer(mt, wrbuf);
+        fputs(wrbuf_cstr(wrbuf), stdout);
+        wrbuf_destroy(wrbuf);
+    }
     fclose(inf);
 }
 
 #if YAZ_HAVE_XML2
 static void marcdump_read_xml(yaz_marc_t mt, const char *fname)
 {
-    xmlNodePtr ptr;
-    xmlDocPtr doc = xmlParseFile(fname);
-    if (!doc)
-        return;
+    WRBUF wrbuf = wrbuf_alloc();
+#if USE_XMLREADER
+    xmlTextReaderPtr reader = xmlReaderForFile(fname, 0 /* encoding */,
+                                               0 /* options */);
 
-    ptr = xmlDocGetRootElement(doc);
-    if (ptr)
+    if (reader)
     {
-        int r;
-        WRBUF wrbuf = wrbuf_alloc();
-        r = yaz_marc_read_xml(mt, ptr);
-        if (r)
-            fprintf(stderr, "yaz_marc_read_xml failed\n");
-        else
+        int ret;
+        while ((ret = xmlTextReaderRead(reader)) == 1)
         {
-            yaz_marc_write_mode(mt, wrbuf);
-            
-            fputs(wrbuf_cstr(wrbuf), stdout);
+            int type = xmlTextReaderNodeType(reader);
+            if (type == XML_READER_TYPE_ELEMENT)
+            {
+                const char *name = (const char *) 
+                    xmlTextReaderConstName(reader);
+                if (!strcmp(name, "record"))
+                {
+                    xmlNodePtr ptr = xmlTextReaderExpand(reader);
+        
+                    int r = yaz_marc_read_xml(mt, ptr);
+                    if (r)
+                        fprintf(stderr, "yaz_marc_read_xml failed\n");
+                    else
+                    {
+                        yaz_marc_write_mode(mt, wrbuf);
+                        
+                        fputs(wrbuf_cstr(wrbuf), stdout);
+                        wrbuf_rewind(wrbuf);
+                    }
+                }
+            }
         }
-        wrbuf_destroy(wrbuf);
+        yaz_marc_write_trailer(mt, wrbuf);
+        fputs(wrbuf_cstr(wrbuf), stdout);
     }
-    xmlFreeDoc(doc);
+#else
+    xmlDocPtr doc = xmlParseFile(fname);
+    if (doc)
+    {
+        xmlNodePtr ptr = xmlDocGetRootElement(doc);
+        for (; ptr; ptr = ptr->next)
+        {
+            if (ptr->type == XML_ELEMENT_NODE)
+            {
+                if (!strcmp((const char *) ptr->name, "collection"))
+                {
+                    ptr = ptr->children;
+                    continue;
+                }
+                if (!strcmp((const char *) ptr->name, "record"))
+                {
+                    int r = yaz_marc_read_xml(mt, ptr);
+                    if (r)
+                        fprintf(stderr, "yaz_marc_read_xml failed\n");
+                    else
+                    {
+                        yaz_marc_write_mode(mt, wrbuf);
+                        
+                        fputs(wrbuf_cstr(wrbuf), stdout);
+                        wrbuf_rewind(wrbuf);
+                    }
+                }
+            }
+        }
+        xmlFreeDoc(doc);
+    }
+#endif
+    yaz_marc_write_trailer(mt, wrbuf);
+    fputs(wrbuf_cstr(wrbuf), stdout);
+    wrbuf_destroy(wrbuf);
 }
 #endif
 
@@ -152,6 +216,7 @@ static void dump(const char *fname, const char *from, const char *to,
         yaz_marc_iconv(mt, cd);
     }
     yaz_marc_xml(mt, output_format);
+    yaz_marc_enable_collection(mt);
     yaz_marc_write_using_libxml2(mt, write_using_libxml2);
     yaz_marc_debug(mt, verbose);
 
@@ -307,6 +372,12 @@ static void dump(const char *fname, const char *from, const char *to,
             fprintf (cfile, "};\n");
         fclose(inf);
     }
+    {
+        WRBUF wrbuf = wrbuf_alloc();
+        yaz_marc_write_trailer(mt, wrbuf);
+        fputs(wrbuf_cstr(wrbuf), stdout);
+        wrbuf_destroy(wrbuf);
+    }
     if (cd)
         yaz_iconv_close(cd);
     yaz_marc_destroy(mt);
