@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1995-2005, Index Data ApS
+ * Copyright (C) 1995-2007, Index Data ApS
  * See the file LICENSE for details.
  *
- * $Id: yaz-xmlquery.c,v 1.2 2006/03/06 08:11:41 adam Exp $
+ * $Id: yaz-xmlquery.c,v 1.9 2007-05-06 20:12:20 adam Exp $
  */
 
 #include <stdlib.h>
@@ -14,13 +14,13 @@
 #include <yaz/pquery.h>
 #include <yaz/test.h>
 
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
 #include <libxml/parser.h>
 #endif
 
 static char *prog = "yaz-xmlquery";
 
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
 void pqftoxmlquery(const char *pqf)
 {
     YAZ_PQF_Parser parser = yaz_pqf_create();
@@ -62,10 +62,10 @@ void pqftoxmlquery(const char *pqf)
 	}
         else
         {
-            char *buf_out = 0;
+            xmlChar *buf_out = 0;
             int len_out = 0;
 
-            xmlDocDumpMemory(doc, (xmlChar **) &buf_out, &len_out);
+            xmlDocDumpMemory(doc, &buf_out, &len_out);
 
             if (!len_out || !buf_out)
 	    {
@@ -117,8 +117,8 @@ void xmlquerytopqf(const char *xmlstr)
 	{
 	    WRBUF w = wrbuf_alloc();
 	    yaz_query_to_wrbuf(w, query);
-	    printf("%s\n", wrbuf_buf(w));
-	    wrbuf_free(w, 1);
+	    printf("%s\n", wrbuf_cstr(w));
+	    wrbuf_destroy(w);
 	}
 	odr_destroy(odr);
 	xmlFreeDoc(doc);
@@ -143,7 +143,7 @@ void xmlfiletopqf(const char *xmlfile)
 	exit(1);
     }
     rewind(f);
-    xmlstr = xmalloc(sz+1);
+    xmlstr = (char *) xmalloc(sz+1);
     xmlstr[sz] = '\0';
     fread(xmlstr, sz, 1, f);
     fclose(f);
@@ -153,7 +153,7 @@ void xmlfiletopqf(const char *xmlfile)
 }
 #endif
 
-void usage()
+void usage(void)
 {
     fprintf(stderr, "%s [-p pqf] [-x xmlfile]\n", prog);
     fprintf(stderr, " -p pqf      reads pqf. write xml to stdout\n");
@@ -163,7 +163,7 @@ void usage()
 
 int main (int argc, char **argv)
 {
-#if HAVE_XML2
+#if YAZ_HAVE_XML2
     char *arg;
     int r;
     int active = 0;
